pilas.actores.puntaje

Package pilas :: Package actores :: Module puntaje |
[hide private]
[frames] | no frames]

# Source Code for Module pilas.actores.puntaje

     1  # -*- encoding: utf-8 -*-
     2  # For Pilas engine - A video game framework.
     3  #
     4  # Copyright 2010 - Pablo Garrido
     5  # License: LGPLv3 (see http://www.gnu.org/licenses/lgpl.html)
     6  #
     7  # Website - http://www.pilas-engine.com.ar
     8  #
     9
    10
    11  import pilas
    12  from pilas.actores import Texto
    13
    14 -class Puntaje(Texto):
    15      """Representa un contador de Puntaje"""
    16
    17 -    def __init__(self, texto='0', x=0, y=0, color=pilas.colores.negro):
    18          """Inicializa el Puntaje.
    19
    20          :param texto: El número inicial del puntaje.
    21          :param x: Posición horizontal para el puntaje.
    22          :param y: Posición vertical para el puntaje.
    23          :param color: Color que tendrá el texto de puntaje.
    24          """
    25          Texto.__init__(self, texto, x=x, y=y)
    26          self.color = color
    27
    28 -    def definir(self, puntaje_variable = '0'):
    29          """Cambia el texto que se mostrará cómo puntaje.
    30
    31          :param puntaje_variable: Texto a definir.
    32          """
    33          self.puntaje_texto = str(puntaje_variable)
    34          self.texto = self.puntaje_texto
    35
    36 -    def aumentar(self, cantidad=1):
    37          """Incrementa el puntaje.
    38
    39          :param cantidad: La cantidad de puntaje que se aumentará.
    40          """
    41          self.definir(int(self.texto) + int(cantidad))
    42
    43 -    def obtener(self):
    44          """Retorna el puntaje en forma de número."""
    45          return int(self.texto)
    46